# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc

from . import MLUtil as MLU
from AI.ML.SL_Reg import *

import numpy as np
from matplotlib import pyplot as plot
from mpl_toolkits.mplot3d import Axes3D

###########################################################################
## Class P19
###########################################################################

class P19 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 250,250 ), style = wx.BORDER_RAISED|wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )


		self.flds = []
		self.idata = []
		self.Xdata = []
		self.Ydata = []

		Vsp19 = wx.BoxSizer( wx.VERTICAL )

		Hsz11 = wx.BoxSizer(wx.HORIZONTAL)

		self.lblm = wx.StaticText(self, wx.ID_ANY, u"m =  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lblm.Wrap(-1)

		Hsz11.Add(self.lblm, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.Sc1 = wx.SpinCtrl(self, wx.ID_ANY, u"m", wx.DefaultPosition, wx.Size(60, -1), wx.SP_ARROW_KEYS, 0, 9999,
		                       0)
		Hsz11.Add(self.Sc1, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.lbl2 = wx.StaticText(self, wx.ID_ANY, u"Number of training", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl2.Wrap(-1)

		Hsz11.Add(self.lbl2, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btnm = wx.Button(self, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz11.Add(self.btnm, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz11, 0, wx.EXPAND, 5)

		Hsz12 = wx.BoxSizer(wx.HORIZONTAL)

		self.lblx = wx.StaticText(self, wx.ID_ANY, u"x (Input/features)=  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lblx.Wrap(-1)

		Hsz12.Add(self.lblx, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fldx = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz12.Add(self.fldx, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btnx = wx.Button(self, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz12.Add(self.btnx, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
		self.btnx.SetToolTip(u"Independent variable")
		Vsp19.Add(Hsz12, 0, wx.EXPAND, 5)

		Hsz13 = wx.BoxSizer(wx.HORIZONTAL)

		self.lbly = wx.StaticText(self, wx.ID_ANY, u"y (Output/target)=  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbly.Wrap(-1)

		Hsz13.Add(self.lbly, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fldy = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz13.Add(self.fldy, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btny = wx.Button(self, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz13.Add(self.btny, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
		self.btny.SetToolTip(u"Dependent variable")
		Vsp19.Add(Hsz13, 0, wx.EXPAND, 5)

		Hsz14 = wx.BoxSizer(wx.HORIZONTAL)

		self.lblt = wx.StaticText(self, wx.ID_ANY, u"Shows plot of Data you enter", wx.DefaultPosition,
		                          wx.DefaultSize, 0)
		self.lblt.Wrap(-1)

		Hsz14.Add(self.lblt, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btntt = wx.Button(self, wx.ID_ANY, u"Show Plot", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz14.Add(self.btntt, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz14, 0, wx.EXPAND, 5)

		Hsz1 = wx.BoxSizer(wx.HORIZONTAL)

		self.Btn1 = wx.Button(self, wx.ID_ANY, u"Comput Thetas", wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz1.Add(self.Btn1, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz1, 0, wx.EXPAND, 5)

		Hsz2 = wx.BoxSizer(wx.HORIZONTAL)

		self.lbl1 = wx.StaticText(self, wx.ID_ANY, u"Theta 0", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl1.Wrap(-1)

		Hsz2.Add(self.lbl1, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fld1 = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY)
		Hsz2.Add(self.fld1, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz2, 0, wx.EXPAND, 5)

		Hsz3 = wx.BoxSizer(wx.HORIZONTAL)

		self.lbl2 = wx.StaticText(self, wx.ID_ANY, u"Theta 1", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl2.Wrap(-1)

		Hsz3.Add(self.lbl2, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fld2 = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY)
		Hsz3.Add(self.fld2, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz3, 0, wx.EXPAND, 5)

		Hsz4 = wx.BoxSizer(wx.HORIZONTAL)

		self.fld3 = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY)
		Hsz4.Add(self.fld3, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz4, 0, wx.EXPAND, 5)

		Hsz5 = wx.BoxSizer(wx.HORIZONTAL)

		self.Btn2 = wx.Button(self, wx.ID_ANY, u"Show Plot line", wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz5.Add(self.Btn2, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL , 5)

		Vsp19.Add(Hsz5, 0, wx.EXPAND, 5)


		self.SetSizer( Vsp19 )
		self.Layout()

		# Connect Events
		self.btnm.Bind(wx.EVT_BUTTON, self.inptri)
		self.btnx.Bind(wx.EVT_BUTTON, self.inpx)
		self.btny.Bind(wx.EVT_BUTTON, self.inpy)
		self.btntt.Bind(wx.EVT_BUTTON, self.pltdata)
		self.Btn1.Bind(wx.EVT_BUTTON, self.comput)
		self.Btn2.Bind(wx.EVT_BUTTON, self.shwplot)

	def __del__( self ):
		pass

	# Virtual event handlers, overide them in your derived class
	def comput(self, event):
		mylnr = Simple_Leaner()
		X_seri = []
		Y_seri = []
		for D in self.idata:
			X_seri.append(float(D[0]))
			Y_seri.append(float(D[1]))
		Theta0 = mylnr.Theta0(X_seri,Y_seri)
		Theta1 = mylnr.Theta1(X_seri,Y_seri)

		self.Y = []

		self.fld1.SetValue(str(Theta0))
		self.fld2.SetValue(str(Theta1))
		self.fld3.SetValue('y = '+str(Theta0)+' + '+str(Theta1)+' . x1 ')
		for D in self.idata:
			self.Y.append(Theta0+Theta1*float(D[0]))
		event.Skip()

	def shwplot(self, event):
		#print('press btn plot')
		X = self.Xdata[:,1]
		y = self.Ydata.transpose()
		y1 = self.Y
		plot.plot(X, y, 'rx', markersize=10)
		plot.ylabel('data y')
		plot.xlabel('data x')
		plot.plot(X, y1, '-')
		plot.show()
		event.Skip()

	def inptri( self, event ):
		#print(self.idata)
		#print(self.flds)
		frm = wx.Dialog(self, -1)
		pnl = MLU.Yselect(frm, self.flds, self.idata)
		#pnl = MyPanel3(frm, self.flds, self.idata)
		frm.SetSize((500,220))
		frm.SetLabel(u'Data you use')
		frm.ShowModal()
		#frm.EndModal((pnl.xMtrx,pnl.yMtrx))
		Xm = pnl.xMtrx
		Ym = pnl.yMtrx
		frm.Destroy()
		self.Xdata= np.matrix(Xm)
		self.Ydata= np.matrix(Ym)

		self.fldx.SetValue( 'np.matrix(xdata)' )
		self.fldy.SetValue( 'np.matrix(ydata)' )


	def inpx( self, event ):
		frm = wx.Dialog(self, -1)
		pnl = MLU.ShowMatrix(frm, self.Xdata)
		#pnl = MyPanel4(frm,self.Xdata)
		frm.SetSize((300,180))
		frm.SetLabel(u'X matrix')
		frm.ShowModal()

		frm.Destroy()
		event.Skip()

	def inpy( self, event ):
		frm = wx.Dialog(self, -1)
		pnl = MLU.ShowMatrix(frm, self.Ydata)
		#pnl = MyPanel4(frm, self.Ydata)
		frm.SetSize((300, 180))
		frm.SetLabel(u'Y matrix')
		frm.ShowModal()

		frm.Destroy()

	def pltdata( self, event ):
		#print(self.Xdata[:,1],self.Ydata[:,0])
		X = self.Xdata[:,1]
		y = self.Ydata.transpose()
		plot.plot(X, y , 'rx', markersize=10)
		plot.ylabel('data y')
		plot.xlabel('data x')
		plot.show()



# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## Please DO NOT Change Panel name (P19)
###########################################################################

import wx
import wx.xrc


###########################################################################
## Class P19 Temp Panel
###########################################################################

class P19 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 250,250 ), style = wx.BORDER_RAISED|wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsp19 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )
		#you can add object in this BoxSizer


		Vsp19.Add( Hsz1, 0, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer


		Vsp19.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer


		Vsp19.Add( Hsz3, 0, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer


		Vsp19.Add( Hsz4, 0, wx.EXPAND, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer

		Vsp19.Add( Hsz5, 0, wx.EXPAND, 5 )


		self.SetSizer( Vsp19 )
		self.Layout()

		# Connect Events


	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def Start(self):
		pass

	def Test(self):
		pass



#In the name of GOD
#Cust Function
#Regresion Problem
# -*- coding: utf-8 -*-
#!usr/bin/env python

from AI.Analiz import *

import numpy as np
from matplotlib import pyplot as plot
from mpl_toolkits.mplot3d import Axes3D

class Cust_Func:
	def __init__(self):
		pass

	def Comput(self, X, y, Theta):
		m = y.size
		costs = (X.dot(Theta) - y) ** 2

		return costs.sum() / (2.0 * m)

	def Gradient_descent(self, X, y, Theta, Alpha, num_iters):
		m = y.size
		J_history = np.zeros(num_iters)
		for i in range(num_iters):
			h = X.dot(Theta)
			errors = h - y
			delta = X.T.dot(errors)
			Theta -= (Alpha / m) * delta
			J_history[i] = self.Comput(X, y, Theta)
		return (Theta, J_history)

	def Gradient_descent2(self, X, y, Theta, Alpha, num_iters):
		m = y.size

		for j in range(num_iters):
			Theta[j] += Theta[j] - (Alpha * (1/m)) * (self.Deter_Cust(X, y, Theta) * X[m] )


	def Cost_Function(self, X, y, Thetas):
		m = y.size
		Dest = 0
		for i in range(m):
			Dest += (self.Hypath(X[i], Thetas) - y[i]) ** 2
		return (1/(2*m))*Dest

	def Hypath(self, X, Theta):
		return np.dot(X, Theta.T)

	def Deter_Cust(self, X, y, Theta):
		m = y.size
		Dest = 0
		for i in range(m):
			Dest += (self.Hypath(X[i], Theta) - y[i])
		return (1/m)*Dest

	def update_theta(self):
		pass

	def __iter__(self):
		pass

	def __reduce__(self):
		pass



# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import AI.ML.GA_Reg as GAR

from . import MLUtil as MLU

import numpy as np
from matplotlib import pyplot as plot
from mpl_toolkits.mplot3d import Axes3D


###########################################################################
## Class P192
###########################################################################

class P19 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 250,250 ), style = wx.BORDER_RAISED|wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		self.flds = []
		self.idata = []
		self.Xdata = []
		self.Ydata = []

		Vsp19 = wx.BoxSizer( wx.VERTICAL )

		Hsz11 = wx.BoxSizer(wx.HORIZONTAL)

		self.lblm = wx.StaticText(self, wx.ID_ANY, u"m =  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lblm.Wrap(-1)

		Hsz11.Add(self.lblm, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.Sc1 = wx.SpinCtrl(self, wx.ID_ANY, u"m", wx.DefaultPosition, wx.Size(60, -1), wx.SP_ARROW_KEYS, 0, 9999,
		                       0)
		Hsz11.Add(self.Sc1, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.lbl2 = wx.StaticText(self, wx.ID_ANY, u"Number of training", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl2.Wrap(-1)

		Hsz11.Add(self.lbl2, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btnm = wx.Button(self, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz11.Add(self.btnm, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz11, 0, wx.EXPAND, 5)

		Hsz12 = wx.BoxSizer(wx.HORIZONTAL)

		self.lblx = wx.StaticText(self, wx.ID_ANY, u"x (Input/features)=  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lblx.Wrap(-1)

		Hsz12.Add(self.lblx, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fldx = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz12.Add(self.fldx, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btnx = wx.Button(self, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz12.Add(self.btnx, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
		self.btnx.SetToolTip(u"Independent variable")
		Vsp19.Add(Hsz12, 0, wx.EXPAND, 5)

		Hsz13 = wx.BoxSizer(wx.HORIZONTAL)

		self.lbly = wx.StaticText(self, wx.ID_ANY, u"y (Output/target)=  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbly.Wrap(-1)

		Hsz13.Add(self.lbly, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fldy = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz13.Add(self.fldy, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btny = wx.Button(self, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz13.Add(self.btny, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
		self.btny.SetToolTip(u"Dependent variable")
		Vsp19.Add(Hsz13, 0, wx.EXPAND, 5)

		Hsz14 = wx.BoxSizer(wx.HORIZONTAL)

		self.lblt = wx.StaticText(self, wx.ID_ANY, u"Shows plot of Data you enter", wx.DefaultPosition,
		                          wx.DefaultSize, 0)
		self.lblt.Wrap(-1)

		Hsz14.Add(self.lblt, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.btntt = wx.Button(self, wx.ID_ANY, u"Show Plot", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz14.Add(self.btntt, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsp19.Add(Hsz14, 0, wx.EXPAND, 5)

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.lblr = wx.StaticText( self, wx.ID_ANY, u"LR a :", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lblr.Wrap( -1 )

		self.lblr.SetToolTip( u"Learning ratting" )

		Hsz1.Add( self.lblr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.Rate = wx.SpinCtrlDouble( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.SP_ARROW_KEYS, 0, 100, 0.01, 0.01 )
		self.Rate.SetDigits( 3 )
		Hsz1.Add( self.Rate, 0, wx.ALL, 5 )


		Vsp19.Add( Hsz1, 0, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lblI = wx.StaticText( self, wx.ID_ANY, u"Iteration", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lblI.Wrap( -1 )

		Hsz2.Add( self.lblI, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.Iter1 = wx.SpinCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.SP_ARROW_KEYS, 0, 10000, 0 )
		Hsz2.Add( self.Iter1, 0, wx.ALL, 5 )


		Vsp19.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, u"Hyp. Plot", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsp19.Add( Hsz3, 0, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn2 = wx.Button( self, wx.ID_ANY, u"Cost. Plot", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btn2, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsp19.Add( Hsz4, 0, wx.EXPAND, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl3 = wx.StaticText( self, wx.ID_ANY, u"Theta ", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz5.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld10 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY )
		Hsz5.Add( self.fld10, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsp19.Add( Hsz5, 0, wx.EXPAND, 5 )


		self.SetSizer( Vsp19 )
		self.Layout()

		# Connect Events
		self.btnm.Bind(wx.EVT_BUTTON, self.inptri)
		self.btnx.Bind(wx.EVT_BUTTON, self.inpx)
		self.btny.Bind(wx.EVT_BUTTON, self.inpy)
		self.btntt.Bind(wx.EVT_BUTTON, self.pltdata)
		#self.btn0.Bind(wx.EVT_BUTTON, self.CompThta)
		self.btn1.Bind( wx.EVT_BUTTON, self.hplt )
		self.btn2.Bind( wx.EVT_BUTTON, self.cstplt )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def inptri( self, event ):
		#print(self.idata)
		#print(self.flds)
		frm = wx.Dialog(self, -1)
		pnl = MLU.Yselect(frm, self.flds, self.idata)
		#pnl = MyPanel3(frm, self.flds, self.idata)
		frm.SetSize((500,220))
		frm.SetLabel(u'Data you use')
		frm.ShowModal()
		#frm.EndModal((pnl.xMtrx,pnl.yMtrx))
		Xm = pnl.xMtrx
		Ym = pnl.yMtrx
		frm.Destroy()
		self.Xdata= np.matrix(Xm,dtype=float)
		self.Ydata= np.matrix(Ym,dtype=float)
		self.X1 = np.array(Xm, dtype=float)
		self.y1 = np.array(Ym, dtype=float)
		print(self.y1)
		self.fldx.SetValue( 'np.matrix(xdata)' )
		self.fldy.SetValue( 'np.matrix(ydata)' )


	def inpx( self, event ):
		frm = wx.Dialog(self, -1)
		pnl = MLU.ShowMatrix(frm, self.Xdata)
		#pnl = MyPanel4(frm,self.Xdata)
		frm.SetSize((300,180))
		frm.SetLabel(u'X matrix')
		frm.ShowModal()

		frm.Destroy()
		event.Skip()

	def inpy( self, event ):
		frm = wx.Dialog(self, -1)
		pnl = MLU.ShowMatrix(frm, self.Ydata)
		#pnl = MyPanel4(frm, self.Ydata)
		frm.SetSize((300, 180))
		frm.SetLabel(u'Y matrix')
		frm.ShowModal()

		frm.Destroy()

	def pltdata( self, event ):
		#print(self.Xdata[:,1],self.Ydata[:,0])
		X = self.Xdata[:,1]
		y = self.Ydata.transpose()
		plot.plot(X, y , 'rx', markersize=10)
		plot.ylabel('data y')
		plot.xlabel('data x')
		plot.show()

	def hplt( self, event ):
		print('H plot')
		alpha = self.Rate.GetValue()
		iterat = self.Iter1.GetValue()
		theta = np.zeros(2)
		y = self.Ydata.transpose()
		m = y.size
		X = np.vstack((np.ones(m), self.X1.T)).T

		Cstfunc = GAR.Cust_Func()

		CF = Cstfunc.Comput(self.X1, self.y1, theta )
		print(CF)
		(theta, J_history) = Cstfunc.Gradient_descent(self.X1, self.y1, theta, alpha, iterat)
		print(theta)
		print(J_history)
		plot.plot(self.X1[:, 1], self.y1, 'rx', markersize=10)
		plot.ylabel('Y data')
		plot.xlabel('X data')
		plot.plot(self.X1[:, 1], self.X1.dot(theta), '-')
		plot.show()
		event.Skip()

	def cstplt( self, event ):
		print('cust plot')
		Cstfunc = GAR.Cust_Func()
		theta0_vals = np.linspace(-10, 10, 100)
		theta1_vals = np.linspace(-1, 4, 100)
		J_vals = np.zeros((theta0_vals.size, theta1_vals.size))
		for i in range(theta0_vals.size):
			for j in range(theta1_vals.size):
				t = np.array([theta0_vals[i], theta1_vals[j]])
				J_vals[i, j] = Cstfunc.Comput(self.X1, self.y1, t)
		plot.contour(theta0_vals, theta1_vals, J_vals, levels=np.logspace(-2, 3, 20))
		plot.show()
		fig = plot.figure()
		ax = fig.add_subplot(111, projection='3d')
		t0, t1 = np.meshgrid(theta0_vals, theta1_vals)
		ax.plot_surface(t0, t1, J_vals)
		plot.show()
		event.Skip()




#In the name of GOD
#This program check menu2.db and program structure
# ! /usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import os


## ====================Open Database======================
import Database.MenuSet2 as MS

from Config.Init import *

Get2Menu = MS.GetData(u'Menu2.db', u'')
Set2Menu = MS.SetData(u'', u'', u'')

##====================Control Table Shame ================
def TestShame():
    Tables = {'Guidir':['Dir','prgdir','hdddir'],'MLAlgo':['MLcod','MLAsrc'],
              'MLPane':['MLPid','MLPfile'],'MLinfo':['MLPid','MLname','MLcod'],
              'PrgDesc':['handlerid','Description'],'access':['acclvlid','userid','acclvl','disenable'],
              'extended':['extid','status','icon','shortcut','help','acclvlid','grpid'],
              'grpitem':['grpid','grpname','grpcnt','grpnl','grpth'],
              'handler':['hamdlerid','prgname','prgdir','paramtr','public','prgno'],
              'menubar':['mbarid','mbarname','mbardir','acclvlid'],
              'mitem':['mbarid','itemid','itemname','itemtyp','extid','handlerid'],
              'panifo':['paninfoid','caption','setting','resize','bstsiz','minsiz','maxsiz','docking','position'],
              'pans':['panid','panname','pandok','pansiz','panlyr','paninfoid','handlerid','acclvlid'],
              'security':['userid','username','password'],
              'toolbar':['toolid','toolname','toolicon','shrttxt','lngtxt','handlerid','acclvlid','tooltype']}
    for t in Tables:
        print(t,Tables[t])

##====================Test Src Directory==================
def TestSrcDir():
	lstHdd = os.listdir(SRC_PATH)
	lstHDDPRG = os.listdir(Src_prg)
	lstDBF = Get2Menu.AllGuiDir()
	#print(lstDBF,lstHdd)
	lstDDb = [d[2].replace('..\\Src\\','') for d in lstDBF]
	#print(lstDDb)
	for row in lstDBF:
		if row[2].replace('..\\Src\\','') in lstHdd:
			print(row,'--------ok')
		elif row[2].replace(Src_prg,'') in lstHDDPRG:
			print(row,'--------ok')
		elif row[2] == '..\\GUI\\Main':
			print(row,'--------ok')
		elif row[2] == '..\\GUI\\Temp':
			print(row,'--------ok')
		else:
			print("this row had a problem",row,'--------',Src_prg)


def TestHandler():
	Allhandler = Get2Menu.AllHndl()
	MainPrgFile = os.listdir(GUI_PATH+'Main\\')
	MitemHandlr = []
	print(Allhandler)
	for row in Allhandler:
		MitemHandlr.append(row)
		if row[1] == 'Demo':
			if row[2][1:3] != str(row[0])[-2:]:
				print("you must change this row:",row)
		elif row[1]+'.py' in MainPrgFile:
			print(row,'--------ok')
		else:
			print(row,'---Other ')
			#MitemHandlr.append(row)

	print(MitemHandlr)
	allhandid = [h[0] for h in MitemHandlr]
	print(allhandid)
	for mitm in Get2Menu.AllSub():
		if mitm[5] in allhandid:
			print(mitm,'--------ok')
		else:
			print("Handler id is not in database: ",mitm)


def main():
	TestSrcDir()
	TestHandler()

if __name__=='__main__':
	main()



#In the name of GOD
#please put your code under here
import numpy as np
from matplotlib import pyplot as plot
import matplotlib.cm as cm
from scipy import optimize
from scipy.io import loadmat

def display_data(X):
    """
    Transforms each input row into a rectangular image part and plots
    the resulting image.
    """
    m, n = X.shape
    example_width = int(np.around(np.sqrt(n)))
    example_height = int(n / example_width)
    display_rows = int(np.sqrt(m))
    display_cols = int(m / display_rows)
    display_array = np.ones((
        display_rows * example_height, display_cols * example_width
    ))
    for i in range(display_rows):
        for j in range(display_cols):
            idx = i * display_cols + j
            image_part = X[idx, :].reshape((example_height, example_width))
            display_array[
                (j * example_height):((j + 1) * example_height),
                (i * example_width):((i + 1) * example_width)
            ] = image_part
    plot.imshow(display_array.T, cm.Greys)
    plot.show()


def sigmoid(x):
    return 1.0 / (1.0 + np.exp(-x))


def cost_function(theta, X, y):
    m = X.shape[0]
    h = sigmoid(X.dot(theta))
    cost = sum(-y * np.log(h) - (1.0 - y) * np.log(1.0 - h))
    grad = X.T.dot(h - y)
    return (cost / m, grad / m)


def cost_function_reg(theta, X, y, lambda_):
    """
    Regularized logistic regression cost function.
    """
    m = X.shape[0]
    cost, gradient = cost_function(theta, X, y)
    reg_cost = (lambda_ / (2.0 * m)) * np.sum(theta[1:] ** 2)
    reg_gradient = (lambda_ / m) * theta
    reg_gradient[0] = 0
    return cost + reg_cost, gradient + reg_gradient


def one_vs_all(X, y, num_labels, lambda_):
    n = X.shape[1]
    all_theta = np.zeros((num_labels, n))
    for c in range(1, num_labels + 1):
        initial_theta = np.zeros(n)
        target = np.vectorize(int)(y == c)
        result = optimize.minimize(
            cost_function_reg,
            initial_theta,
            args=(X, target, lambda_),
            method='CG',
            jac=True,
            options={
                'maxiter': 50,
                'disp': False,
            }
        )
        theta = result.x
        cost = result.fun
        print('Training theta for label %d | cost: %f' % (c, cost))
        all_theta[c - 1, :] = theta
    return all_theta


def predict_one_vs_all(theta, X):
    # adding one to compensate label offset
    return 1 + np.argmax(sigmoid(X.dot(theta.T)), axis=1)


#In the name of GOD
#please put your code under here

import wx

def size():
    return (-1,-1)

def main (panel=None):
    #print 'out'
    q = wx.GetActiveWindow()
    p = wx.GetApp()
    
    if str(q) == 'None':
        p.Exit()

    else:
        #print q.m_mgr
        if 'timer' in dir(q):
            q.timer.Stop()
        q.m_mgr.UnInit()
        q.Destroy()

    
if __name__ == '__main__':
    main (None)



#In the name of God
#Utility for Machin Learning Panel Parameter and Algorithms
# -*- coding: utf-8 -*-

import wx
import wx.dataview
###########################################################################
## Class Yselect
###########################################################################


class Yselect ( wx.Panel ):

	def __init__( self, parent,felds, data, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 498,215 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.VLC1 = wx.dataview.DataViewListCtrl( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )

		for f1 in felds:
			self.VLC1.AppendTextColumn(f1, width=-1, align=wx.ALIGN_LEFT)

		for dt in data:
			DD = ()
			for d in dt:
				DD = DD + (str(d),)
			self.VLC1.AppendItem(DD)


		Hsz1.Add( self.VLC1, 1, wx.ALL|wx.EXPAND, 5 )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		RB1Choices = felds
		self.RB1 = wx.RadioBox( self, wx.ID_ANY, u"What of this y", wx.DefaultPosition, wx.DefaultSize, RB1Choices, 1, wx.RA_SPECIFY_COLS )
		self.RB1.SetSelection( 0 )
		Vsz1.Add( self.RB1, 1, wx.ALL, 5 )

		self.btn = wx.Button( self, wx.ID_ANY, u"ok", wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz1.Add( self.btn, 0, wx.ALL, 5 )


		Hsz1.Add( Vsz1, 0, wx.EXPAND, 5 )


		self.SetSizer( Hsz1 )
		self.Layout()

		# Connect Events
		self.RB1.Bind(wx.EVT_RADIOBOX, self.thisy)
		self.btn.Bind( wx.EVT_BUTTON, self.clos )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def thisy(self, event):
		yfld = self.RB1.GetSelection()
		#print(yfld)
		colpos = yfld
		icol = self.VLC1.GetColumn(yfld)
		#print(colpos)
		xvalu = []
		yvalu = []
		for r in range(self.VLC1.GetItemCount()):
			yvalu.append( self.VLC1.GetValue(r,colpos) )
		for r in range(self.VLC1.GetItemCount()):
			xcol = [1]
			for c in range(self.VLC1.GetColumnCount()):
				if c != colpos:
					xcol.append(self.VLC1.GetValue(r,c))
			xvalu.append(xcol)
		self.xMtrx = xvalu
		self.yMtrx = yvalu
		#print(xvalu)
		#print(yvalu)
		event.Skip()

	def clos( self, event ):
		q = self.GetParent()
		q.Close()
		event.Skip()

###########################################################################
## Class ShowMatrix
###########################################################################

class ShowMatrix ( wx.Panel ):

	def __init__( self, parent, Matrx, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 300,180 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz = wx.BoxSizer( wx.VERTICAL )
		iMatrix = '[\n'
		mlst = Matrx.tolist()
		#mshp = np.matrix.shape
		#print(mlst)
		#print(mshp)

		for r in range(len(mlst)):
			iMatrix += '['
			for c in range(len(mlst[r])):
				#print(mlst[r][c])
				iMatrix += str(mlst[r][c])+'  '
			iMatrix += ']\n'
		iMatrix += ']'


		self.Txt = wx.TextCtrl( self, wx.ID_ANY, iMatrix, wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE )
		Vsz.Add( self.Txt, 1, wx.ALL|wx.EXPAND, 5 )

		self.btn = wx.Button( self, wx.ID_ANY, u"ok", wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz.Add( self.btn, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( Vsz )
		self.Layout()

		# Connect Events
		self.btn.Bind( wx.EVT_BUTTON, self.okit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def okit( self, event ):
		q = self.GetParent()
		q.Close()
		event.Skip()



# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
from Config.Init import *

###########################################################################
## Class MyPanel1
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 150,350 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, u"MenuBar", wx.DefaultPosition, wx.DefaultSize, 0 )

		self.btn1.SetBitmap( wx.Bitmap( ICON16_PATH+u"menubar.png", wx.BITMAP_TYPE_ANY ) )
		Vsz1.Add( self.btn1, 0, wx.ALL|wx.EXPAND, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, u"MenuItem", wx.DefaultPosition, wx.DefaultSize, 0 )

		self.btn2.SetBitmap( wx.Bitmap( ICON16_PATH+u"menu_item.png", wx.BITMAP_TYPE_ANY ) )
		Vsz1.Add( self.btn2, 0, wx.ALL|wx.EXPAND, 5 )

		self.btn3 = wx.Button( self, wx.ID_ANY, u"ToolBar", wx.DefaultPosition, wx.DefaultSize, 0 )

		self.btn3.SetBitmap( wx.Bitmap( ICON16_PATH+u"toolbar.png", wx.BITMAP_TYPE_ANY ) )
		Vsz1.Add( self.btn3, 0, wx.ALL|wx.EXPAND, 5 )

		self.btn4 = wx.Button( self, wx.ID_ANY, u"Database", wx.DefaultPosition, wx.DefaultSize, 0 )

		self.btn4.SetBitmap( wx.Bitmap( ICON16_PATH+u"database.png", wx.BITMAP_TYPE_ANY ) )
		Vsz1.Add( self.btn4, 0, wx.ALL|wx.EXPAND, 5 )

		self.btn5 = wx.Button( self, wx.ID_ANY, u"Form", wx.DefaultPosition, wx.DefaultSize, 0 )

		self.btn5.SetBitmap( wx.Bitmap( ICON16_PATH+u"form.png", wx.BITMAP_TYPE_ANY ) )
		Vsz1.Add( self.btn5, 0, wx.ALL|wx.EXPAND, 5 )

		self.btn6 = wx.Button( self, wx.ID_ANY, u"Panel", wx.DefaultPosition, wx.DefaultSize, 0 )

		self.btn6.SetBitmap( wx.Bitmap( ICON16_PATH+u"panel.png", wx.BITMAP_TYPE_ANY ) )
		Vsz1.Add( self.btn6, 0, wx.ALL|wx.EXPAND, 5 )


		Vsz1.Add( ( 0, 0), 1, wx.EXPAND, 5 )

		self.btnbak = wx.Button( self, wx.ID_ANY, u"Close", wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz1.Add( self.btnbak, 0, wx.ALL|wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btn1.Bind( wx.EVT_BUTTON, self.Dombr )
		self.btn2.Bind( wx.EVT_BUTTON, self.Doitm )
		self.btn3.Bind( wx.EVT_BUTTON, self.Dotlb )
		self.btn4.Bind( wx.EVT_BUTTON, self.Dodbf )
		self.btn5.Bind( wx.EVT_BUTTON, self.Dofrm )
		self.btn6.Bind( wx.EVT_BUTTON, self.Dopnl )
		self.btnbak.Bind( wx.EVT_BUTTON, self.Docols )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def Dombr( self, event ):
		from Temps.MenuDev1 import MyPanel3
		self.b = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		self.panel = MyPanel3(self.b)
		self.b.SetSize((500, 180))
		self.b.Show()


	def Doitm( self, event ):
		from Temps.MenuDev1 import MyPanel1
		self.b = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		self.panel = MyPanel1(self.b)
		self.b.SetSize((650, 300))
		self.b.Show()

	def Dotlb( self, event ):
		from GUI.API.ToolBar1 import MyPanel1
		self.b = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		self.panel = MyPanel1(self.b)
		self.b.SetSize((540, 280))
		self.b.Show()

	def Dodbf( self, event ):
		event.Skip()

	def Dofrm( self, event ):
		event.Skip()

	def Dopnl( self, event ):
		event.Skip()

	def Docols( self, event ):
		q = self.GetParent()
		q.Close()



#In The name of God
#!/usr/bin/env python
# -*- codnig: utf-8 -*-
import sqlalchemy
from sqlalchemy import create_engine
from sqlalchemy import MetaData
from sqlalchemy.orm import sessionmaker
from sqlalchemy import Table,Column,Integer,String,Text

from Config.Init import *

class Get:
	def __init__(self, DBF, engine,**kwargs):
		'''

		:param DBF: Database-name
		:param engine: ['sqlite','mysql','postgresql','oracle','sqlserver']
		:param kwargs: user  password  host
		'''
		if len(kwargs) == 3:
			self.user = kwargs['user']
			self.pswrd = kwargs['password']
			self.host = kwargs['host']

		self.DBF = DBF

		if engine == 'sqlite':
			self.myengin = create_engine('sqlite:///'+self.DBF, echo=False)
		if engine == 'postgresql':
			self.myengin = create_engine('postgresql://'+self.user+':'+self.pswrd+'@'+self.host+'/'+self.DBF)
			# psycopg2
			#self.myengin = create_engine('postgresql+psycopg2://scott:tiger@localhost/'+self.DBF)
			# pg8000
			#self.myengin = create_engine('postgresql+pg8000://scott:tiger@localhost/'+self.DBF)
		if engine == 'mysql':
			self.myengin = create_engine('mysql://'+self.user+':'+self.pswrd+'@'+self.host+'/'+self.DBF)
			# mysqlclient (a maintained fork of MySQL-Python)
			#self.myengin = create_engine('mysql+mysqldb://scott:tiger@localhost/foo')
			# PyMySQL
			#self.myengin = create_engine('mysql+pymysql://scott:tiger@localhost/foo')
		if engine == 'oracle':
			self.myengin = create_engine('oracle://'+self.user+':'+self.pswrd+'@'+self.host+':1521/'+self.DBF)
			# self.myengin = create_engine('oracle+cx_oracle://scott:tiger@tnsname')
		if engine == 'sqlserver':
			self.myengin = create_engine('mssql+pymssql://'+self.user+':'+self.pswrd+'@'+self.host+':1521/'+self.DBF)
			#self.myengin = create_engine('mssql+pyodbc://scott:tiger@mydsn')

		meta = MetaData()


	def openSQL(self, sqlfile):
		with open(sqlfile) as f:
			self.alltext = f.readlines()
		return  self.alltext

	def GetFromSql(self):
		with self.myengin.connect() as conn :
			session = sessionmaker()
			result = conn.execute(self.alltext[0])
			conn.close()
			#conn.commit()
		return result

	def GetFromString(self, sqlstring):
		with self.myengin.connect() as conn:
			result = conn.execute(sqlstring)
			return result.fetchall()





class Post:
	def __init__(self, DBF, table, Data, engine, **kwargs):
		'''

		:param DBF:
		:param Table:
		:param Data:
		:param engine:
		:param kwargs: user  pswrd  host
		'''
		if len(kwargs) == 3:
			self.user = kwargs['user']
			self.pswrd = kwargs['password']
			self.host = kwargs['host']
		self.DBF = DBF
		self.Data = Data
		self.table = table
		self.metadata = MetaData()


		if engine == 'sqlite':
			self.myengin = create_engine('sqlite:///'+self.DBF, echo=False)
		if engine == 'postgresql':
			self.myengin = create_engine('postgresql://'+self.user+':'+self.pswrd+'@'+self.host+'/'+self.DBF)
		if engine == 'mysql':
			self.myengin = create_engine('mysql://'+self.user+':'+self.pswrd+'@'+self.host+'/'+self.DBF)
		if engine == 'oracle':
			self.myengin = create_engine('oracle://'+self.user+':'+self.pswrd+'@'+self.host+':1521/'+self.DBF)
		if engine == 'sqlserver':
			self.myengin = create_engine('mssql+pymssql://'+self.user+':'+self.pswrd+'@'+self.host+':1521/'+self.DBF)

	def Addrecord(self,Filed,Data):
		thstbl = Table(self.table,self.metadata,autoload=True,autoload_with=self.myengin)
		with self.myengin.connect() as conn:
			ins = thstbl.insert()
			#print(str(ins))
			ins = thstbl.insert().values(Data)
			result = conn.execute(ins)

	def Updaterecord(self,Field,Data):
		pass

	def Deleterecord(self,Data):
		pass


# In the name of God
# -*- coding: utf-8 -*-
# !usr/bin/env python

import wx
import DCC1.MLDev2 as MLV
from Config.Init import *


class telframe(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, style=wx.FRAME_FLOAT_ON_PARENT | wx.DEFAULT_FRAME_STYLE)
        self.parent = parent


        self.panel = MLV.MyPanel1(self)

    def closeit(self):
        self.Close(True)


def size():
    return (-1, -1)


def main(panel=None):
    #locale = wx.Locale(wx.LANGUAGE_ENGLISH)

    parent = panel.GetParent()

    frame = telframe(parent)
    frame.SetTitle(u'Machin Learning Design')
    frame.SetSize((555, 500))
    frame.Show()


if __name__ == '__main__':
    main()



#In the name of GOD
#please put your code under here
############ Description ############
##  This is a Sample Demo File
##  Only four line you can use for
##  Description
##
############### End ###############
# -*- coding: utf-8 -*-
#!usr/bin/env python



#In the name of GOD

import keras
import wx
import wx.dataview
import PIL.Image as pil

import tensorflow as tf

wx.FindWindowByName()
wx.Choice.GetStringSelection()
wx.Choice.SetStringSelection()
wx.Panel.Destroy()

wx.Bitmap.FromBuffer()
pil.fromarray().save()
wx.DC.DrawBitmap()

wx.CheckBox.GetValue()


from keras.models import Sequential
from keras.layers import Conv2D, MaxPool2D, Dense, Flatten, Dropout, Input
from keras.applications.vgg16 import VGG16
from keras.applications.vgg19 import VGG19
from keras.layers import ReLU
from keras import layers



imodel = Sequential()
imodel.add(keras.Input(shape=(200,200,3)))
Conv2D(filters=16,kernel_size=(4,4),strides=(1,1),padding='valid',activation=None)
Dense(units=16, activation=None)
MaxPool2D(pool_size=(2,2),strides=None,padding='valid')
Dropout(rate=0.4,noise_shape=None,seed=None)
Flatten()



ReLU(max_value=None,negative_slope=0,threshold=0)

VGG16(weights="imagenet", include_top=False, input_shape=(IMAGE_SIZE, IMAGE_SIZE, 3),pooling=None
      ,classes=1000,classifier_activation="softmax")
VGG19(weights="imagenet", include_top=False, input_shape=(200,200,3),pooling=None,
      classes=1000,classifier_activation="softmax")

imodel.summary()
imodel.add(Dropout())
imodel.fit( x=None,y=None,batch_size=None,epochs=1,verbose='auto',callbacks=None, #{on_train_begin, on_epoch_begin, on_train_batch_begin, on_train_batch_end, on_epoch_end, on_train_end}
            validation_split=0.,validation_data=None,shuffle=True,class_weight=None,sample_weight=None,
            initial_epoch=0,steps_per_epoch=None,validation_steps=None,validation_batch_size=None,
            validation_freq=1,max_queue_size=10,workers=1,use_multiprocessing=False)

from keras.models import Functional
from keras.layers import AveragePooling2D

fmodel = keras.models.Functional()

fmodel.layers.append()

from six.moves import _thread

_thread.start_new_thread()

wx.EVT_THREAD


# In the name of God
# ! /usr/bin/env python
# -*- coding: utf-8 -*-
# Start some program and splash

from Allimp import wx
from Config.Init import *

class MySplashScreen(wx.adv.SplashScreen):
    def __init__(self, window):
        self.window = window
        self.config = wx.GetApp().GetConfig()

        mysplash = self.config.Read("Splash")
        bmp = wx.Bitmap(mysplash, wx.BITMAP_TYPE_ANY)

        wx.adv.SplashScreen.__init__(self, bmp,
                                 wx.adv.SPLASH_CENTRE_ON_SCREEN | wx.adv.SPLASH_TIMEOUT,
                                 7000, None, style=wx.BORDER_NONE|
                                     #wx.BORDER_SIMPLE|
                                     #wx.FRAME_NO_TASKBAR|
                                     wx.STAY_ON_TOP)

        self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)
        self.count = 0
        #wx.Sleep(1)
        self.CrtCtrl()
        self.tmr = wx.Timer(self, 1)
        self.tmr.Start(75)

        self.Bind(wx.EVT_CLOSE, self.OnClose)

        self.Bind(wx.EVT_TIMER, self.TimerHandler, self.tmr)

        wx.BeginBusyCursor()

        self.fc = wx.CallLater(2000, self.ShowMain)


    def CrtCtrl(self):
        rect = self.GetClientRect()
        new_size = (rect.width, 9)
        self.text = wx.StaticText(self,-1,"Loading...",pos=(0, rect.height-9),size=(new_size),style=wx.ALIGN_CENTRE_HORIZONTAL)
        self.text.SetBackgroundColour(wx.WHITE)
        self.text.SetForegroundColour(wx.BLACK)

        self.gauge = wx.Gauge(self,-1,range=50,size=(-1, 9),pos=(0, rect.height))
        #rect = self.GetClientRect()

        self.gauge.SetSize(new_size)
        self.SetSize((rect.width, rect.height + 9))
        #self.gauge.SetPosition((0, rect.height))

    def TimerHandler(self, event):

        self.count = self.count + 1
        if self.count >= 90:
            self.count = 0
        self.gauge.SetValue(self.count)


    def OnClose(self, evt):
        # Make sure the default handler runs too so this window gets destroyed

        self.Hide()
        self.tmr.Stop()
        # if the timer is still running then go ahead and show the main frame now
        if self.fc.IsRunning():
            self.fc.Stop()
            self.ShowMain()
        evt.Skip()

    def ShowMain(self):
        wx.CallAfter(wx.EndBusyCursor)


        SIZE = wx.Size(eval(self.config.Read(u'WinSize')))
        frame = self.window.MainWin()

        frame.SetSize(SIZE)

        frame.SetPosition((0,0))

        frame.EnableFullScreenView(True)
        #frame.ShowFullScreen()
        frame.Show()

        if self.fc.IsRunning():
            self.Raise()
        # wx.CallAfter(frame.ShowTip)


# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################
import datetime
import os
import shutil
import zipfile
import zipimport
import tarfile
import requests
#import cv2
import wx
import wx.xrc
import wx.dataview

from Config.Init import *
import Res.Allicons as icon

import Database.MenuSet2 as MS
import Database.PostGet as PG
import GUI.proman as pro
import importlib
#import importlib.util

import AI.Analiz
import AI.OpnSrc as OS
from AI.Analiz import *
from AI.Generats import *

_ = wx.GetTranslation

###########################################################################
## Class MyPanel7
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 570,470 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.getMData = MS.GetData(u'Menu2.db', u'')
		self.setMDate = MS.SetData(u'', u'', u'')

		self.Splt1 = wx.SplitterWindow( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.SP_3D|wx.SP_LIVE_UPDATE|wx.SP_NO_XP_THEME|wx.SP_THIN_SASH )
		self.Splt1.Bind( wx.EVT_IDLE, self.Splt1OnIdle )

		self.P1 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz2 = wx.BoxSizer( wx.VERTICAL )

		self.Titr1 = wx.StaticText( self.P1, wx.ID_ANY, _(u"List of Programs and Tools can download"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.Titr1.Wrap( -1 )

		Vsz2.Add( self.Titr1, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )

		self.TLC1 = wx.dataview.TreeListCtrl( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.dataview.TL_DEFAULT_STYLE )
		self.TLC1.AppendColumn( _(u"Name"), 200, wx.ALIGN_LEFT, wx.COL_RESIZABLE )
		self.TLC1.AppendColumn( _(u"ID"), 25, wx.ALIGN_LEFT, wx.COL_RESIZABLE )

		Vsz2.Add( self.TLC1, 1, wx.EXPAND |wx.ALL, 5 )

		#Hsz1 = wx.BoxSizer( wx.HORIZONTAL )


		#Vsz2.Add( Hsz1, 0, wx.EXPAND, 5 )

		# Hsz2 = wx.BoxSizer( wx.HORIZONTAL )
		#
		# self.CntSrv = wx.Button( self.P1, wx.ID_ANY, _(u"Connect to server "), wx.DefaultPosition, wx.DefaultSize, 0 )
		# Hsz2.Add( self.CntSrv, 1, wx.ALL, 5 )
		#
		#
		# Vsz2.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn1.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_add.png', wx.BITMAP_TYPE_ANY))
		self.btn1.SetBitmap(icon.add_package.GetBitmap())
		self.btn1.SetToolTip(_(u"Add"))
		Hsz3.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn2.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_edit.png', wx.BITMAP_TYPE_ANY))
		self.btn2.SetBitmap(icon.edit_package.GetBitmap())
		self.btn2.SetToolTip(_(u"Edit"))
		Hsz3.Add( self.btn2, 0, wx.ALL, 5 )

		self.btn3 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn3.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_delete.png', wx.BITMAP_TYPE_ANY))
		self.btn3.SetBitmap(icon.delete_package.GetBitmap())
		self.btn3.SetToolTip(_(u"Delete"))
		Hsz3.Add( self.btn3, 0, wx.ALL, 5 )

		self.btn4 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn4.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_form.png', wx.BITMAP_TYPE_ANY))
		self.btn4.SetBitmap(icon.application_form.GetBitmap())
		self.btn4.SetToolTip(_(u"Preview"))
		Hsz3.Add( self.btn4, 0, wx.ALL, 5 )

		self.btn5 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn5.SetBitmap(wx.Bitmap(ICON16_PATH + u'update.png', wx.BITMAP_TYPE_ANY))
		self.btn5.SetBitmap(icon.update.GetBitmap())
		self.btn5.SetToolTip(_(u"UpDate"))
		Hsz3.Add( self.btn5, 0, wx.ALL, 5 )

		self.btn6 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn6.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_put.png', wx.BITMAP_TYPE_ANY))
		self.btn6.SetBitmap(icon.accept_button.GetBitmap())
		self.btn6.SetToolTip(_(u"Apply"))
		Hsz3.Add( self.btn6, 0, wx.ALL, 5 )

		self.btn7 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn7.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_lightning.png', wx.BITMAP_TYPE_ANY))
		self.btn7.SetBitmap(icon.lightning.GetBitmap())
		self.btn7.SetToolTip(_(u"Generate"))
		Hsz3.Add( self.btn7, 0, wx.ALL, 5 )


		Vsz2.Add( Hsz3, 0, wx.EXPAND, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		self.P2 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		self.Titr2 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Description"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.Titr2.Wrap( -1 )

		Vsz3.Add( self.Titr2, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz11 = wx.BoxSizer( wx.HORIZONTAL )

		self.Descr = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE )
		Hsz11.Add( self.Descr, 1, wx.ALL|wx.EXPAND, 5 )


		Vsz3.Add( Hsz11, 1, wx.EXPAND, 5 )

		# Hsz12 = wx.BoxSizer( wx.HORIZONTAL )
		#
		# self.btndon = wx.Button(self.P2, wx.ID_ANY, _(u"Download"), wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		# Hsz12.Add(self.btndon, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
		#
		# self.gug1 = wx.Gauge(self.P2, wx.ID_ANY, 100, wx.DefaultPosition, wx.DefaultSize, wx.GA_HORIZONTAL)
		# self.gug1.SetValue(0)
		# Hsz12.Add(self.gug1, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
		#
		# Vsz3.Add( Hsz12, 0, wx.EXPAND, 5 )

		Hsz13 = wx.BoxSizer( wx.HORIZONTAL )

		self.extchk = wx.Button(self.P2, wx.ID_ANY, _(u"Extract, Check and Show File"), wx.DefaultPosition, wx.DefaultSize,
		                        0)
		Hsz13.Add(self.extchk, 1, wx.ALL, 5)


		Vsz3.Add( Hsz13, 0, wx.EXPAND, 5 )

		Hsz14 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self.P2, wx.ID_ANY, _(u"To Directory"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl2.Wrap( -1 )

		Hsz14.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.dir2 = wx.DirPickerCtrl( self.P2, wx.ID_ANY, wx.EmptyString, _(u"Select a folder"), wx.DefaultPosition, wx.DefaultSize, wx.DIRP_DEFAULT_STYLE|wx.DIRP_SMALL )
		Hsz14.Add( self.dir2, 1, wx.ALL, 5 )


		Vsz3.Add( Hsz14, 0, wx.EXPAND, 5 )

		self.lin1 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
		Vsz3.Add( self.lin1, 0, wx.EXPAND |wx.ALL, 5 )

		# Hsz15 = wx.BoxSizer( wx.HORIZONTAL )
		#
		# self.chk1 = wx.CheckBox( self.P2, wx.ID_ANY, _(u"Check it ..."), wx.DefaultPosition, wx.DefaultSize, 0 )
		# Hsz15.Add( self.chk1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		# Vsz3.Add( Hsz15, 0, wx.EXPAND, 5 )

		Hsz16 = wx.BoxSizer( wx.VERTICAL )

		self.lbl3 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Message"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz16.Add( self.lbl3, 0, wx.ALL, 5 )

		self.msag = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE )
		Hsz16.Add( self.msag, 1, wx.ALL|wx.EXPAND, 5 )


		Vsz3.Add( Hsz16, 1, wx.EXPAND, 5 )


		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		self.Splt1.SplitVertically( self.P1, self.P2, 255 )
		Vsz1.Add( self.Splt1, 1, wx.EXPAND, 5 )

		self.filllist()


		self.SetSizer( Vsz1 )
		self.Layout()

		self.listfilezip = []
		self.infopacktxt = []

		# Connect Events
		self.TLC1.Bind(wx.dataview.EVT_DATAVIEW_SELECTION_CHANGED, self.slctitm, id=wx.ID_ANY)
		#self.CntSrv.Bind( wx.EVT_BUTTON, self.consrv )
		self.btn1.Bind( wx.EVT_BUTTON, self.addit )
		self.btn2.Bind( wx.EVT_BUTTON, self.editit )
		self.btn3.Bind( wx.EVT_BUTTON, self.delit )
		self.btn4.Bind( wx.EVT_BUTTON, self.prw )
		self.btn5.Bind( wx.EVT_BUTTON, self.upd )
		self.btn6.Bind( wx.EVT_BUTTON, self.aply )
		self.btn7.Bind( wx.EVT_BUTTON, self.gnrt )
		#self.btn8.Bind( wx.EVT_BUTTON, self.mnuid )
		#self.btndon.Bind(wx.EVT_BUTTON, self.dnlod)
		self.extchk.Bind(wx.EVT_BUTTON, self.extrc)
		self.dir2.Bind( wx.EVT_DIRPICKER_CHANGED, self.thsdir )
		#self.btn9.Bind( wx.EVT_BUTTON, self.dnlod )
		#self.chk1.Bind( wx.EVT_CHECKBOX, self.chkdon )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def filllist(self):

		Aroot = self.TLC1.GetRootItem()
		self.root1 = self.TLC1.AppendItem(Aroot, "Programs you Download it")
		self.root2 = self.TLC1.AppendItem(Aroot, "Programs in your Account")
		self.root3 = self.TLC1.AppendItem(Aroot, "Programs that you Upload ")
		self.root4 = self.TLC1.AppendItem(Aroot, "Unpacked downloaded Programs")
		#self.root5 = self.TLC1.AppendItem(Aroot, "Programs file in your HDD ")

		dirct = ['Downloads','Account','Uploads','Fount']
		dirdt2 = ['API', 'AUI', 'GUI', 'MLA', 'MLP', 'PRG']
		dcods = {'API': 6122, 'AUI': 6155, 'PRG': 6111, 'GUI': 6177, 'MLA': 6133, 'MLP': 6144}
		roots = [self.root1,self.root2,self.root3,self.root4]
		#roots = [self.root1,  self.root3, self.root4]
		i=0
		for d in dirct:
			mylist = os.listdir(UTILITY_PATH+d+'\\')
			if i == 3:
				for d in dirdt2:
					mylist2 = os.listdir(UTILITY_PATH + 'Fount\\' + d + '\\')
					mychild = self.TLC1.AppendItem(self.root4, 'Unpacked')
					self.TLC1.SetItemText(mychild, 0, d)
					self.TLC1.SetItemText(mychild, 1, str(dcods[d])[-3:])
					for file in mylist2:
						if file != '__init__.py' and file != '__pycache__':
							child2 = self.TLC1.AppendItem(mychild, d)
							self.TLC1.SetItemText(child2, 0, file)
							self.TLC1.SetItemText(child2, 1, str(dcods[d]))
				for f in mylist:
					if f != '__init__.py' and f != '__pycache__' and f not in dirdt2:
						mychld = self.TLC1.AppendItem(self.root4,d)
						self.TLC1.SetItemText(mychld,0,f)
						self.TLC1.SetItemText(mychld,1,'^^^')

			else:
				for fil in mylist:
					if fil != '__init__.py' and fil != '__pycache__':
						myfil = fil.replace(UTILITY_PATH+d+'\\','')
						mychld = self.TLC1.AppendItem(roots[i],d)
						self.TLC1.SetItemText(mychld,0,myfil)
						self.TLC1.SetItemText(mychld,1,'>>>')
			i += 1


	def fillfilds(self, Data):
		self.Descr.SetValue(Data[0])
		#self.fld1.SetValue(Data[1])
		self.dir2.SetPath(Data[1])
		self.Refresh()
		self.Layout()

	def slctitm(self, event):
		D = ['','','']
		self.fillfilds(D)
		itm = self.TLC1.GetSelection()
		if itm:
			txt = self.TLC1.GetItemText(itm, 0)
			cod = self.TLC1.GetItemText(itm, 1)
			par = self.TLC1.GetItemParent(itm)
			rot = self.TLC1.GetItemText(par, 0)
		else:
			txt = ''
			code = 6666
		#print(txt,rot)
		if 'Download' in txt :
			Discrpt = "Programs you download from Site in to your HardDisk"
			Pathsrc = UTILITY_PATH+'Downloads'
		elif 'Upload' in txt:
			Discrpt = "Programs that you Upload to your Account for Sell or Send"
			Pathsrc = UTILITY_PATH+'Uploads'
		elif 'Unpacked' in txt:
			Discrpt = "Unpacked program that download from Site and see files in it"
			Pathsrc = UTILITY_PATH+'Account'

		else:
			if 'pack' in txt and not '.sfn' in txt and cod == '>>>': # and 'Download' in rot:
				if 'Download' in rot:
					ipath = UTILITY_PATH+'Downloads'+SLASH
				if 'Upload' in rot:
					ipath = UTILITY_PATH+'Uploads'+SLASH
				with zipfile.ZipFile(ipath+txt,'r') as zf:
					for ifi in zf.namelist():
						if '.sfn' in ifi:
							itxt = zf.read(ifi)
				Discrpt = self.ShowDscr(itxt)
				Pathsrc = UTILITY_PATH+"Fount"
			elif '.sfn' in txt:
				with open(UTILITY_PATH+"Fount"+SLASH+txt, 'r', encoding='utf-8') as f:
					itxt=bytes(f.read(), 'utf-8')
				Discrpt = self.ShowDscr(itxt)
				Pathsrc = UTILITY_PATH+"Fount"
			else:
				Discrpt = ""
				Pathsrc = ""

		D = [Discrpt,Pathsrc]
		self.fillfilds(D)
		if '.py' in txt:
			self.thsfile = UTILITY_PATH+'Fount\\'+rot+SLASH+txt
		else:
		 	self.thsfile = ''
		#print(self.thsfile)

	def ShowDscr( self, sfntxt):
		#print(sfntxt)
		txt = sfntxt.decode('utf-8')
		#print(txt.find('*/'))
		idx = txt.find('*/')
		if idx != -1:
			#print(txt[idx+2:])
			return txt[idx+2:]
		else:
			return ''

	def addit( self, event ):
		def addzip(izipname,chld2):
			thsfil,pthcod = self.slctfil()
			#print(thsfil,pthcod)
			if thsfil == '':
				wx.MessageBox(_(" The file is in Zip file Please select new file!"))
			elif thsfil == -1:
				wx.MessageBox(_("Only file in Src Directory path send to zip file"))
			else:
				self.listfilezip.append(thsfil)
				self.add2zip(izipname, chld2,str(pthcod) )

		itm = self.TLC1.GetSelection()
		if itm.IsOk() :
			txt = self.TLC1.GetItemText(itm, 0)
		else:
			txt = ''
		#print(txt)

		if 'Upload' in txt:
			ischld =  self.TLC1.GetNextItem(itm)
			if 'download' in self.TLC1.GetItemText(ischld, 0):
				addtim = datetime.datetime.now().isoformat(timespec='minutes').replace(':','_').replace('-','_')
				izipname = 'packzip'+addtim+'.tm5'
				chld2 = self.TLC1.AppendItem(self.root3,izipname)
				self.TLC1.SetItemText(chld2,0,izipname)
				self.TLC1.SetItemText(chld2,1,'6666')
				addzip(izipname,chld2)
			else:
				if 'packzip' in self.TLC1.GetItemText(ischld, 0):
					izipname = self.TLC1.GetItemText(ischld, 0)
					chld2 = ischld
					addzip(izipname,chld2)
		else:
			ischld = self.TLC1.GetNextItem(itm)
			if 'packzip' in txt:
				izipname = self.TLC1.GetItemText(ischld, 0)
				chld2 = self.TLC1.GetSelection()
				addzip(izipname,chld2)
				#print(self.TLC1.GetItemText(itm, 0))
		#print(self.listfilezip)
		#self.add2zip(izipname,chld2)
		event.Skip()

	def slctfil(self):
		dlg = wx.FileDialog(self,'Select your Source Code',SRC_PATH,wildcard ='*.*' ,style=wx.FD_DEFAULT_STYLE)
		dlg.ShowModal()
		myfile = dlg.GetPath()
		dlg.Destroy()
		if myfile in self.listfilezip:
			return '',''
		for src in Src_Pth:
			if src.capitalize() in myfile.capitalize():
				#self.writinfo(myfile.capitalize().replace(src.capitalize(),''),Src_Dir[Src_Pth[src]],Src_Pth[src],str(os.stat(myfile).st_size))
				self.writinfo(myfile.split("\\")[-1], Src_Dir[Src_Pth[src]], Src_Pth[src],str(os.stat(myfile).st_size))
				return myfile,Src_Dir[Src_Pth[src]]
		return -1,-1

	def writinfo(self, file, code,titl,size):
		self.infopacktxt.append((titl,str(code),file,size))

	def editit( self, event ):
		itm = self.TLC1.GetSelection()
		txt = self.TLC1.GetItemText(itm, 0)
		cod = self.TLC1.GetItemText(itm, 1)
		#print(txt,cod)
		if cod != '' and cod.isdigit() and cod != '6666':
			myindx = iter(self.infopacktxt)
			#print(self.infopacktxt)
			for i in range(len(self.infopacktxt)):
				if txt in next(myindx):
					#print(i)
					self.infopacktxt.remove(self.infopacktxt[i])
					for i, v in enumerate(self.listfilezip):
						if txt in v:
							self.listfilezip.remove(self.listfilezip[i])
					thsfil, pthcod = self.slctfil()
					self.ins2zip( itm,thsfil,str(pthcod) )
					self.listfilezip.append(thsfil)
		#else:
		#	print('Not this')
		#print(self.infopacktxt)
		#print(self.listfilezip)
		event.Skip()

	def delit( self, event ):
		itm = self.TLC1.GetSelection()
		txt = self.TLC1.GetItemText(itm, 0)
		cod = self.TLC1.GetItemText(itm, 1)
		#print(txt, cod)
		if cod != '' and cod.isdigit() and cod != '6666':
			for indx,item in enumerate(self.infopacktxt):
				if txt in item:
					#print(indx)
					self.infopacktxt.remove(item)
					self.del2zip(itm)
					for i, v in enumerate(self.listfilezip):
						if txt in v:
							self.listfilezip.remove(self.listfilezip[i])

		#print(self.infopacktxt)
		#print(self.listfilezip)
		event.Skip()

	def prw( self, event ):
		txt = self.TLC1.GetItemText(self.TLC1.GetSelection(), 0)
		rot = self.TLC1.GetItemParent(self.TLC1.GetSelection())
		roottxt = self.TLC1.GetItemText(rot, 0)
		if '.py' in txt:
			self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
			self.Pnl = OS.SrcPanel(self.Frm, self.thsfile)
			self.Frm.SetMenuBar(OS.MyMenuBar1(u'Pro'))
			self.Frm.SetSize((700, 560))
			self.Frm.SetLabel(self.thsfile)
			self.Frm.Show()
		event.Skip()

	def upd( self, event ):
		self.TLC1.DeleteAllItems()
		self.filllist()
		self.Refresh()
		event.Skip()

	def aply( self, event ):
		itm = self.TLC1.GetSelection()
		if itm:
			txt = self.TLC1.GetItemText(itm, 0)
			cod = self.TLC1.GetItemText(itm, 1)
			par = self.TLC1.GetItemParent(itm)
			rot = self.TLC1.GetItemText(par, 0)
		if self.dir2.GetPath() == '' or self.dir2.GetPath() == UTILITY_PATH+'Fount':
			wx.MessageBox(_("Please Change your path or select a correct path"))
			return

		if '.sfn' in txt:
			with open(UTILITY_PATH+'Fount'+SLASH+txt, 'r', encoding='utf-8') as f:
				if_lst = self.list_py_file( f.readlines() )
			#print(if_lst)
			if SRC_PATH not in self.dir2.GetPath():
				print(SRC_PATH, self.dir2.GetPath())
			for i in if_lst:
				if 'PRG' in i[0]:
					shutil.copy(UTILITY_PATH+'Fount'+SLASH+i[0]+SLASH+i[2],self.dir2.GetPath())
				else:
					shutil.copy(UTILITY_PATH + 'Fount' + SLASH + i[0] + SLASH + i[2], SRC_PATH+i[0])

			wx.MessageBox(_(" All file Successfull copy to Src path"))

			shutil.make_archive( UTILITY_PATH+'Account'+SLASH+txt , 'tar', UTILITY_PATH + 'Fount')
			answer=wx.MessageBox(_("We Pack tar file all file to Account path Do you like delete file ?"),style=wx.YES_NO)
			if answer==2:
				os.remove(UTILITY_PATH+'Fount'+SLASH+txt)
				for j in if_lst:
					os.remove(UTILITY_PATH+'Fount'+SLASH+j[0]+SLASH+j[2])
			pass
		event.Skip()

	def list_py_file(self, txtlins):
		mylst = []
		for t in txtlins:
			if '/*' not in t:
				mylst.append(t.replace('\n','').split(','))
		return mylst

	def gnrt( self, event ):

		txt = self.TLC1.GetItemText(self.TLC1.GetSelection(),0)
		rot = self.TLC1.GetItemParent(self.TLC1.GetSelection())
		roottxt = self.TLC1.GetItemText(rot,0)
		if 'packzip' in txt and 'Upload' in roottxt:
			with open(TEMPS_PATH + 'infopack'+txt.lstrip('packzip').rstrip('.tm5')+'.sfn', 'a', encoding='utf-8') as f:
				for t in self.infopacktxt:
					#print(t[2])
					f.write(t[0]+','+t[1]+','+t[2]+','+t[3]+'\n')
				f.write('/*=========Desc.=========*/\n'+self.Descr.GetValue())

			for fil in self.listfilezip:
				shutil.copy(fil, TEMPS_PATH)

			with zipfile.ZipFile(UTILITY_PATH+'Uploads'+SLASH+txt,'w', compression=zipfile.ZIP_DEFLATED) as zp:
				self.zipdir(TEMPS_PATH, zp)

			for zf in os.listdir(TEMPS_PATH):
				if os.path.isfile(TEMPS_PATH+zf):
					os.unlink(TEMPS_PATH+zf)

			self.TLC1.DeleteAllItems()
			self.filllist()
			self.Refresh()


		event.Skip()

	def zipdir(self, path, ziph):
		# ziph is zipfile handle
		for root, dirs, files in os.walk(path):
			for file in files:
				ziph.write(path+file,file)
	# def mnuid( self, event ):
	# 	event.Skip()
	def add2zip(self,zipname,child,pathcod):
		SP1 = {v: k for k, v in Src_Pth.items()}
		SD1 = {v: k for k, v in Src_Dir.items()}
		chld3 = self.TLC1.AppendItem(child,zipname)
		#print(self.listfilezip[-1].split('\\')[-1])
		#self.TLC1.SetItemText(chld3,0,self.listfilezip[-1].capitalize().replace(SP1[SD1[int(pathcod)]].capitalize(),''))
		self.TLC1.SetItemText(chld3, 0,self.listfilezip[-1].split('\\')[-1])
		self.TLC1.SetItemText(chld3,1,pathcod)

	def ins2zip(self, itm, filname, pathcod):
		SP1 = {v: k for k, v in Src_Pth.items()}
		SD1 = {v: k for k, v in Src_Dir.items()}

		self.TLC1.SetItemText(itm, 0, filname.replace(SP1[SD1[int(pathcod)]],'').split('\\')[-1])
		self.TLC1.SetItemText(itm, 1, pathcod)

	def del2zip(self, itm):
		self.TLC1.DeleteItem(itm)

	def thsdir( self, event ):
		event.Skip()

	# def dnlod( self, event ):
	# 	event.Skip()

	def extrc(self, event):
		txt = self.TLC1.GetItemText(self.TLC1.GetSelection(), 0)
		rot = self.TLC1.GetItemParent(self.TLC1.GetSelection())
		roottxt = self.TLC1.GetItemText(rot, 0)
		msg = ''
		nmlst = ''

		if 'Download' in roottxt:
			#print(txt)
			with zipfile.ZipFile(UTILITY_PATH+'Downloads'+SLASH+txt,'r') as fz:
				namelist = fz.namelist()
				#print(namelist)
				for nl in namelist:
					if '.sfn' in nl:
						fz.extract(nl,UTILITY_PATH+'Fount')
						nmlst = nl
			if nmlst != '':
				with open(UTILITY_PATH+'Fount'+SLASH+nmlst,'r') as f:
					lstfil = f.readlines()
				for fl in lstfil:
					if '/*' in fl:
						break
					finfo = fl.split(',')
					msg += 'Copy file Src/%s [%s] size %s'%(finfo[0]+'/'+finfo[2],finfo[1],finfo[3])
					self.msag.SetValue(msg)
					with zipfile.ZipFile(UTILITY_PATH + 'Downloads' + SLASH + txt, 'r') as fz:
						fz.extract(finfo[2],UTILITY_PATH+'Fount'+SLASH+finfo[0])
				#shutil.copy(TEMPS_PATH+fl,)
		event.Skip()

	def Splt1OnIdle( self, event ):
		self.Splt1.SetSashPosition( 255 )
		self.Splt1.Unbind( wx.EVT_IDLE )




#In the name of GOD
#open source file of algorithm or panle algorithm
# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import wx.stc as stc

from Config.Init import *

import os
import sys

import keyword

_ = wx.GetTranslation

if wx.Platform == '__WXMSW__':
    faces = {'times': 'Times New Roman',
             'mono': 'Courier New',
             'helv': 'Arial', #'Tahoma', #'Arial',

             'other': 'Comic Sans MS',
             'size': 10,
             'size2': 8,
             }
elif wx.Platform == '__WXMAC__':
    faces = {'times': 'Times New Roman',
             'mono': 'Monaco',
             'helv': 'Arial',
             'other': 'Comic Sans MS',
             'size': 12,
             'size2': 10,
             }
else:
    faces = {'times': 'Times',
             'mono': 'Courier',
             'helv': 'Helvetica',
             'other': 'new century schoolbook',
             'size': 12,
             'size2': 10,
             }


class PythonSTC(stc.StyledTextCtrl):
    fold_symbols = 2

    def __init__(self, parent, PyFile):
        stc.StyledTextCtrl.__init__(self, parent)

        self.StyleClearAll()  # Reset all to be like the default

        self.CmdKeyAssign(ord('B'), stc.STC_SCMOD_CTRL, stc.STC_CMD_ZOOMIN)
        self.CmdKeyAssign(ord('N'), stc.STC_SCMOD_CTRL, stc.STC_CMD_ZOOMOUT)


        self.SetLexer(stc.STC_LEX_PYTHON)
        self.SetKeyWords(0, " ".join(keyword.kwlist))

        self.SetProperty("fold", "1")
        self.SetProperty("tab.timmy.whinge.level", "1")
        self.SetMargins(0, 0)

        # Indentation and tab stuff
        self.SetIndent(4)  # Proscribed indent size for wx
        self.SetIndentationGuides(True)  # Show indent guides
        self.SetBackSpaceUnIndents(True)  # Backspace unindents rather than delete 1 space
        self.SetTabIndents(True)  # Tab key indents
        self.SetTabWidth(4)  # Proscribed tab size for wx
        self.SetUseTabs(False)  # Use spaces rather than tabs, or
        # TabTimmy will complain!

        self.SetViewWhiteSpace(False)
        self.SetIndentationGuides(stc.STC_STYLE_INDENTGUIDE)

        self.SetEOLMode(stc.STC_EOL_LF)
        # self.SetBufferedDraw(False)
        #self.SetViewEOL(True)
        #self.SetEOLMode(stc.STC_EDGE_NONE)
        #self.SetUseAntiAliasing(True)
        self.SetMarginType(1, stc.STC_MARGIN_NUMBER)
        #self.SetMarginMask(1, 0)
        #self.SetMarginWidth(1, 40)

        # Global default styles for all languages
        self.StyleSetSpec(stc.STC_STYLE_DEFAULT, "face:%(helv)s,size:%(size)d" % faces)



        # Global default styles for all languages
        self.StyleSetSpec(stc.STC_STYLE_DEFAULT, "face:%(helv)s,size:%(size)d" % faces)
        self.StyleSetSpec(stc.STC_STYLE_LINENUMBER, "back:#C0C0C0,face:%(helv)s,size:%(size2)d" % faces)
        self.StyleSetSpec(stc.STC_STYLE_CONTROLCHAR, "face:%(other)s" % faces)
        self.StyleSetSpec(stc.STC_STYLE_BRACELIGHT, "fore:#FFFFFF,back:#0000FF,bold")
        self.StyleSetSpec(stc.STC_STYLE_BRACEBAD, "fore:#000000,back:#FF0000,bold")

        # Python styles
        # Default
        self.StyleSetSpec(stc.STC_P_DEFAULT, "fore:#000000,face:%(helv)s,size:%(size)d" % faces)
        # Comments
        self.StyleSetSpec(stc.STC_P_COMMENTLINE, "fore:#007F00,face:%(other)s,size:%(size)d" % faces)
        # Number
        self.StyleSetSpec(stc.STC_P_NUMBER, "fore:#007F7F,size:%(size)d" % faces)
        # String
        self.StyleSetSpec(stc.STC_P_STRING, "fore:#7F007F,face:%(helv)s,size:%(size)d" % faces)
        # Single quoted string
        self.StyleSetSpec(stc.STC_P_CHARACTER, "fore:#7F007F,face:%(helv)s,size:%(size)d" % faces)
        # Keyword
        self.StyleSetSpec(stc.STC_P_WORD, "fore:#00007F,bold,size:%(size)d" % faces)
        # Triple quotes
        self.StyleSetSpec(stc.STC_P_TRIPLE, "fore:#7F0000,size:%(size)d" % faces)
        # Triple double quotes
        self.StyleSetSpec(stc.STC_P_TRIPLEDOUBLE, "fore:#7F0000,size:%(size)d" % faces)
        # Class name definition
        self.StyleSetSpec(stc.STC_P_CLASSNAME, "fore:#0000FF,bold,underline,size:%(size)d" % faces)
        # Function or method name definition
        self.StyleSetSpec(stc.STC_P_DEFNAME, "fore:#007F7F,bold,size:%(size)d" % faces)
        # Operators
        self.StyleSetSpec(stc.STC_P_OPERATOR, "bold,size:%(size)d" % faces)
        # Identifiers
        self.StyleSetSpec(stc.STC_P_IDENTIFIER, "fore:#000000,face:%(helv)s,size:%(size)d" % faces)
        #self.StyleSetSpec(wx.stc.STC_P_IDENTIFIER, 'fore:#000000')
        # Comment-blocks
        self.StyleSetSpec(stc.STC_P_COMMENTBLOCK, "fore:#7F7F7F,size:%(size)d" % faces)
        # End of line where string is not closed
        self.StyleSetSpec(stc.STC_P_STRINGEOL, "fore:#000000,face:%(mono)s,back:#E0C0E0,eol,size:%(size)d" % faces)

        #self.StyleSetSpec(stc.STC_TD_STRIKEOUT)
        #self.SetTabDrawMode(stc.STC_TD_STRIKEOUT)

        self.SetCaretForeground("BLUE")

        self.StyleSetFontEncoding(stc.STC_STYLE_DEFAULT,wx.FONTENCODING_CP1256)#    wx.FONTENCODING_UTF8)

        #print(self.GetCodePage())

        # register some images for use in the AutoComplete box.
        # self.RegisterImage(1, images.Smiles.GetBitmap())
        # self.RegisterImage(2,
        #    wx.ArtProvider.GetBitmap(wx.ART_NEW, size=(16,16)))
        # self.RegisterImage(3,
        #    wx.ArtProvider.GetBitmap(wx.ART_COPY, size=(16,16)))

        with open(PyFile, encoding=u'utf-8') as fobj:
            text = fobj.read()

        self.SetText(text)


    def slctal(self):
        self.SelectAll()


###########################################################################
## Class MyPanel2
###########################################################################

class SrcPanel ( wx.Panel ):

	def __init__( self, parent, pyFile, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 680,455 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.pyFile = pyFile
		self.ischanged = False

		self.SrcAlg = PythonSTC(self, pyFile)

		#self.SrcAlg.GetCurrentPos()

		Hsz1.Add( self.SrcAlg, 1, wx.EXPAND |wx.ALL, 5 )

		Vsz1.Add( Hsz1, 1, wx.EXPAND, 5 )

		self.SetSizer( Vsz1 )
		self.Layout()


		self.Bind(wx.stc.EVT_STC_CHARADDED, self.editfile, id=wx.ID_ANY)
		self.SrcAlg.Bind(wx.EVT_CHAR_HOOK, self.kyhok)


	def __del__( self ):
		pass


	def editfile(self, event):
		if self.SrcAlg.GetUndoCollection() and not self.ischanged:
			ilbl = self.GetParent().GetLabel()
			self.GetParent().SetLabel(u'*' + ilbl )
			self.ischanged = True

	def kyhok(self, event):
		#print(u'hook',self.ischanged)
		self.editfile(event)
		event.Skip()

	def newstc(self, pyFile):
		self.SrcAlg.ClearAll()
		with open(pyFile, encoding=u'utf-8') as fobj:
			text = fobj.read()
		self.SrcAlg.SetText(text)
		#self.SrcAlg.SetTextRaw(pyFile)

	def opnstc(self, pyFile):
		self.SrcAlg.ClearAll()
		with open(pyFile, encoding=u'utf-8') as fobj:
			text = fobj.read()
		self.SrcAlg.SetText(text)







###########################################################################
## Class MyMenuBar1
###########################################################################

class MyMenuBar1 ( wx.MenuBar ):

	def __init__( self , extmnu=u''):
		wx.MenuBar.__init__ ( self, style = 0 )

		mymnu = {_(u"File"): [(61,_(u'New'),u'',self.newsrc),(62,_(u'Open...'),u'',self.opnsrc),(63,u'',u'',u''),(64,_(u'Save'),u'',self.savsrc),
		                   (65,_(u'Save As...'),u'',self.savasit),(66,u'',u'',u''),(67,u'IDLE editor',u'',self.idlebat),
		                      (68,u'',u'',u''),(69,_(u'Close'),u'',self.closit)],
		         _(u"Edit"): [(71,_(u'Cut'),u'',self.cutit),(72,_(u'Copy'),u'',self.copyit),(73,_(u'Paste'),u'',self.pastit),
		                   (74,u'',u'',u''),(75,_(u'Select All'),u'',self.slctal)] }
		if extmnu == u'Pro':
			mymnu[_(u'Add')] = [(81,_(u'line-close'),_(u'add close code to button function'),self.clos_lin),
			                 (82,_(u'line-getdata'),_(u'get data from fields textctrl '),self.get_lin),
			                 (83,_(u'line-putdata'),_(u'put data to fields textctrl'),self.put_lin),
			                 (84,_(u'line-fillnull'),_(u'fill empty record in all data'),self.null_lin)]

		elif extmnu == u'MLA':
			mymnu[_(u'Add')] = [(91,_(u'Import Numpy'),u'',self.impnum),(92,_(u'Import matplotlib'),u'',self.impmat),
			                 (93,_(u'Import Axes 3D'),u'',self.impa3d)]
			#mymnu[_(u'MLA Dev')] = [(50,_(u'Add this file'),u'',self.toML)]
		elif extmnu == u'AL':
			mymnu[_(u'Add')] = [(91,_(u'Import Numpy'),u'',self.impnum),(92,_(u'Import matplotlib'),u'',self.impmat),
			                 (93,_(u'Import Axes 3D'),u'',self.impa3d),(94,u'',u'',u''),
			                 (95,_(u'MLA Utility(Y select)'),u'',self.impmlu),(96,_(u'MLA Utility(Show Matrix)'),u'',self.impmlu)]
			#mymnu[_(u'MLA Dev')] = [(50, _(u'Add this file'), u'', self.toML)]


		self.Itms = []
		m = 0
		self.Mnus = []
		s = 0

		for mn in mymnu:
			self.Mnus.append( wx.Menu() )
			for it in mymnu[mn]:
				if it[1] != u'':
					self.Itms.append( wx.MenuItem(self.Mnus[s], it[0], it[1], it[2], wx.ITEM_NORMAL) )
					self.Mnus[s].Append(self.Itms[m])
					self.Bind(wx.EVT_MENU, it[3], id=it[0])
					m += 1
				else:
					self.Mnus[s].AppendSeparator()
			self.Append(self.Mnus[s], mn)
			s += 1

		if extmnu == u"Pro":
			self.DfDir = SRC_PATH
		elif extmnu == u'MLA':
			self.DfDir = Src_mla #SRC_PATH+'MLA\\'
		elif extmnu == u'AL':
			self.DfDir = Src_mlp #SRC_PATH+"MLP\\"
		else:
			self.DfDir = MAP

		self.Bind(wx.EVT_MENU_OPEN, self.Doinit, id=self.GetId())



	def __del__(self):
		pass

	# Virtual event handlers, overide them in your derived class
	def Doinit(self, event):
		frm = self.GetFrame()
		#print(frm)
		self.pnl = frm.GetChildren()[0]
		self.pyfile = self.pnl.pyFile
		self.SrcTxt = self.pnl.SrcAlg

	def newsrc(self, event):
		#print(self.pyfile)
		#print(self.pnl.ischanged)
		if self.pnl.ischanged:
			iyesno = wx.MessageBox(_(u'Do you like to save change'),style=wx.YES_NO)
			#print(iyesno)
			if iyesno == 8:
				return
			else:
				#print(self.pyfile,self.pnl.pyFile)
				self.savsrc(event)
				self.pnl.ischanged = False
				self.pnl.pyFile = u'untitle'
				self.newsrc(event)
		else:
			if u'untitle' in self.pyfile.lower():
				wx.MessageBox(_(u'Please work in this file or close it then use new file'))
			else:
				#print(u'untitle file')
				if self.DfDir == Src_mlp:   #+"MLPane\\":
					self.pnl.newstc(GUI_PATH + u'Temp\\Muntitle.py')
				else:
					self.pnl.newstc(GUI_PATH+u'Temp\\untitle.py')
				self.GetParent().SetLabel(u'untitle')
		event.Skip()

	def opnsrc(self, event):
		with wx.FileDialog(self, _("Open a file"), defaultDir=self.DfDir,wildcard="Python files (*.py)|*.py",
		                   style=wx.FD_OPEN) as fileDialog:
			if fileDialog.ShowModal() == wx.ID_CANCEL:
				return
			pathname = fileDialog.GetPath()
			#self.pyfile = pathname
			self.pnl.pyFile = pathname
			self.pnl.opnstc(pathname)
			self.GetParent().SetLabel(pathname)
		event.Skip()

	def savsrc(self, event):
		if u'untitle.py' in self.pyfile:
			with wx.FileDialog(self, _("Save new file"), defaultDir=self.DfDir,wildcard="Python files (*.py)|*.py",
			                   style=wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT) as fileDialog:
				if fileDialog.ShowModal() == wx.ID_CANCEL:
					return  # the user changed their mind
				# save the current contents in the file
				pathname = fileDialog.GetPath()
				# print(pathname)
				try:
					with open(pathname, 'w', encoding='utf-8') as f:
						f.write(self.SrcTxt.GetText())
				except IOError:
					print('file error')
				self.pnl.pyFile = pathname
				self.pnl.opnstc(pathname)
				self.GetParent().SetLabel(pathname)
		else:
			try:
				with open(self.pyfile, 'w', encoding='utf-8') as f:
					f.write(self.SrcTxt.GetText())
					#self.SrcTxt.SaveFile(self.pyfile)
			except IOError:
				print('File not write had error')
			wx.MessageBox(_(u'You save to file change successful.'))
			self.pnl.ischanged = False
			self.GetParent().SetLabel(self.pyfile)

		event.Skip()

	def savasit(self, event):
		with wx.FileDialog(self, _("Save As new file"), defaultDir=self.DfDir, wildcard="Python files (*.py)|*.py",
		                   style=wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT) as fileDialog:
			if fileDialog.ShowModal() == wx.ID_CANCEL:
				return  # the user changed their mind
			# save the current contents in the file
			pathname = fileDialog.GetPath()
			# print(pathname)
			try:
				with open(pathname, 'w', encoding='utf-8') as f:
					f.write(self.SrcTxt.GetText())
			except IOError:
				print('file error')
			#self.SrcTxt.SaveFile(pathname)
			self.pnl.pyFile = pathname
			self.pnl.opnstc(pathname)
			self.GetParent().SetLabel(pathname)
		event.Skip()

	def closit(self, event):
		q = self.GetParent()
		q.Close()

	def cutit(self, event):
		self.SrcTxt.Cut()
		event.Skip()

	def copyit(self, event):
		self.SrcTxt.Copy()
		event.Skip()

	def pastit(self, event):
		self.SrcTxt.Paste()
		event.Skip()

	def slctal(self, event):
		self.SrcTxt.SelectAll()
		event.Skip()

	def clos_lin(self, event):
		self.SrcTxt.AddText("\t\tq = self.GetParent()\n\t\tq.Close()\n")
		event.Skip()

	def get_lin(self, event):
		self.AnalizFile()
		if self.ctltxt == [] and self.chosls == [] and self.chkbox == [] and self.rdobox == [] and self.rdobtn == [] and self.spinct==[] and self.spincd == []:
			wx.MessageBox(_(u'No any part of Panel for get data! Please use one of this object: \
		                  wx.TextCtrl wx.Choice wx.CheckBox wx.RadioBox'))
		else:
			i = 0
			for obj in self.ctltxt:
				self.SrcTxt.AddText("\t\tD%s = " % str(i) + obj + ".GetValue()\n")
				i += 1
			for obj in self.chosls:
				self.SrcTxt.AddText("\t\tD%s = " % str(i) + obj + ".GetSelection()\n")
				i += 1
			for obj in self.chkbox:
				self.SrcTxt.AddText("\t\tD%s = " % str(i) + obj + ".GetValue()\n")
				i += 1
			for obj in self.rdobox:
				self.SrcTxt.AddText("\t\tD%s = " % str(i) + obj + ".GetSelection()\n")
				i += 1
			for obj in self.rdobtn:
				self.SrcTxt.AddText("\t\tD%s = " % str(i) + obj + ".GetValue()\n")
				i += 1

			for obj in self.spinct:
				self.SrcTxt.AddText("\t\t" + obj + ".GetValue( )\n" )
				i += 1
			for obj in self.spincd:
				self.SrcTxt.AddText("\t\t" + obj + ".GetValue( )\n" )
				i += 1

		self.SrcTxt.AddText("\t\t#### you can return data in your own format here ###\n")
		event.Skip()

	def put_lin(self, event):
		self.AnalizFile()
		if self.ctltxt == [] and self.chosls == [] and self.chkbox == [] and self.rdobox == [] and self.rdobtn == [] and self.spinct==[] and self.spincd == []:
			wx.MessageBox(_(u'No any part of Panel for Put data! Please use one of this object: \
				                  wx.TextCtrl wx.Choice wx.CheckBox wx.RadioBox wx.RadioButton'))
		else:

			self.SrcTxt.AddText("\t\t#Data = [] #Put your data in list or use at argumant in function\n")
			i = 0
			for obj in self.ctltxt:
				self.SrcTxt.AddText("\t\t"  + obj + ".SetValue( Data[%s] )\n" % str(i) )
				i += 1
			for obj in self.chosls:
				self.SrcTxt.AddText("\t\t"  + obj + ".SetSelection( Data[%s] )\n" % str(i) )
				i += 1
			for obj in self.chkbox:
				self.SrcTxt.AddText("\t\t"  + obj + ".SetValue( Data[%s] )\n" % str(i) )
				i += 1
			for obj in self.rdobox:
				self.SrcTxt.AddText("\t\t"  + obj + ".SetSelection( Data[%s] )\n" % str(i) )
				i += 1
			for obj in self.rdobtn:
				self.SrcTxt.AddText("\t\t"  + obj + ".SetValue( Data[%s] )\n" % str(i) )
				i += 1
			for obj in self.spinct:
				self.SrcTxt.AddText("\t\t" + obj + ".SetValue( Data[%s] )\n" % str(i) )
				i += 1
			for obj in self.spincd:
				self.SrcTxt.AddText("\t\t" + obj + ".SetValue( Data[%s] )\n" % str(i) )
				i += 1


		event.Skip()

	def null_lin(self, event):
		self.AnalizFile()
		if self.ctltxt == [] and self.chosls == [] and self.chkbox == [] and self.rdobox == []:
			wx.MessageBox(_(u'No any part of Panel for Put data! Please use one of this object: \
						                  wx.TextCtrl wx.Choice wx.CheckBox wx.RadioBox'))
		else:
			self.SrcTxt.AddText("\t\t#Data = [u'',u'',...] #Put empty data in list\n")
			self.SrcTxt.AddText("\t\t#self.PutData( Data ) #Send empty data to Put Data Function\n")

		event.Skip()

	def AnalizFile(self):
		self.ctltxt = []
		self.chkbox = []
		self.rdobox = []
		self.rdobtn = []
		self.chosls = []
		self.spinct = []
		self.spincd = []
		lins = self.SrcTxt.GetLineCount()
		for l in range(lins):
			if u'wx.TextCtrl' in self.SrcTxt.GetLine(l):
				self.ctltxt.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))
			if u'wx.Choice' in self.SrcTxt.GetLine(l):
				self.chosls.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))
			if u'wx.CheckBox' in self.SrcTxt.GetLine(l):
				self.chkbox.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))
			if u'wx.RadioBox' in self.SrcTxt.GetLine(l):
				self.rdobox.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))
			if u'wx.RadioButton' in self.SrcTxt.GetLine(l):
				self.rdobtn.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))
			if u'wx.SpinCtrl' in self.SrcTxt.GetLine(l):
				self.spinct.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))
			if u'wx.SpinCtrlDouble' in self.SrcTxt.GetLine(l):
				self.spincd.append(self.SrcTxt.GetLineText(l).split('=')[0].lstrip('\t').rstrip(' '))

	def impnum(self, event):
		self.SrcTxt.AddText(u"import numpy as np \n")

	def impmat(self, event):
		self.SrcTxt.AddText(u"from matplotlib import pyplot as plot \n")

	def impa3d(self, event):
		self.SrcTxt.AddText(u"from mpl_toolkits.mplot3d import Axes3D \n")


	def impmlu(self, event):
		pass

	def getCurntLineNumber(self):
		print(self.SrcTxt.gtcurLine())

	def idlebat(self, event):
		for pth in sys.path:
			if 'lib' in pth[-3:]:
				os.system(pth + "\\idlelib\\" + "idle.bat")

# def toML(self, event):
	# 	print(self.pnl.pyFile)
	# 	ifil = self.pnl.pyFile.split('\\')[-1].replace(u'.py',u'')
	# 	print(ifil)
	# 	if self.pnl.pyFile == GUI_PATH+u'Temp\\untitle.py':
	# 		wx.MessageBox(_(u'Please save your work then Do this perosse.'))
	# 		self.savasit(event)
	# 	elif self.pnl.pyFile == GUI_PATH+u'Temp\\Muntitle.py':
	# 		wx.MessageBox(_(u'Please save your work then Do this perosse.'))
	# 		self.savasit(event)
	# 	else:
	# 		print(self.DfDir)
	# 		MLpnl = self.GetGrandParent()
	# 		if self.DfDir == Src_mlp: #SRC_PATH+u'mlp\\':
	# 			mylstml = MLpnl.getMData.AllML(u'join MLPane on MLinfo.MLPid = MLPane.MLPid')
	# 			print(mylstml)
	# 			tclslct = MLpnl.TLC1.GetSelection()
	# 			if MLpnl.getMData.MLPansFils(u" where MLPane.MLPfile = '%s' " %ifil ) != []:
	# 				wx.MessageBox(_(u'File is exist please change it'))
	# 			else:
	# 				lebls = [u'Par. Pane Name', u'Par. Pane code', u'Par. Pane file']
	# 				data = [ifil]
	# 				dlg = wx.Dialog(self.GetFrame(), -1)
	# 				pnl = MyPanel4(dlg, lebls, data)
	# 				dlg.SetSize((480, 190))
	# 				dlg.SetLabel(_(u'Add MLA to List'))
	# 				dlg.ShowModal()
	# 				if pnl.acpt:
	# 					algnm = pnl.fld1.GetValue()
	# 					algcd = pnl.fld2.GetValue()
	# 					algid = pnl.fld4.GetValue()
	# 				dlg.Destroy()
	# 				#print(algid, algnm, algcd)
	# 				#print(MLpnl.codings)
	# 				if algnm != u'' or algcd != u'' or algid != u'':
	# 					if int(algid) > MLpnl.codings[0] and int(algid) < MLpnl.codings[1]:
	# 						#print(u'to database')
	# 						#MLpnl.setMDate.Table = u'MLinfo'
	# 						#MLpnl.setMDate.Additem(u' MLPid, MLname, MLcod', [int(algid), algnm, algcd])
	# 						MLpnl.setMDate.Table = u'MLPane'
	# 						MLpnl.setMDate.Additem(u' MLPid, MLPfile', [algid, ifil])
	# 						wx.MessageBox(_(u'Your source Add to list Successfully.'))
	# 					else:
	# 						wx.MessageBox(_(u'Please attend to coding range!'))
	# 				else:
	# 					wx.MessageBox(_(u'Some fields is empty or wrong ! try again!'))
	#
	#
	# 		if self.DfDir == Src_mla: #SRC_PATH+u'mla\\':
	# 			mylstml = MLpnl.getMData.AllML(u'join MLAlgo on MLAlgo.MLcod = MLinfo.MLcod')
	# 			print(mylstml)
	# 			tclslct = MLpnl.TLC1.GetSelection()
	# 			#algnm = MLpnl.TLC1.GetItemText(tclslct, 0)
	# 			#algcd = MLpnl.TLC1.GetItemText(tclslct, 1)
	# 			if MLpnl.getMData.MLAlgoFils(u" where MLAlgo.MLAsrc = '%s' " %ifil ) != []:
	# 				wx.MessageBox(_(u'File is exist please change it'))
	# 			else:
	# 				lebls = [u'Algorithm Name', u'Algorithm Code', u'Algorithm file']
	# 				data = [ifil]
	# 				dlg = wx.Dialog(self.GetFrame(), -1)
	# 				pnl = MyPanel4(dlg, lebls, data)
	# 				dlg.SetSize((480, 190))
	# 				dlg.SetLabel(_(u'Add MLA to List'))
	# 				dlg.ShowModal()
	# 				if pnl.acpt:
	# 					algnm = pnl.fld1.GetValue()
	# 					algcd = pnl.fld2.GetValue()
	# 					algid = pnl.fld4.GetValue()
	# 				dlg.Destroy()
	# 				#print(algid,algnm,algcd)
	# 				#print(MLpnl.codings)
	# 				if algnm != u'' or algcd != u'' or algid != u'':
	# 					if int(algid) > MLpnl.codings[0] and int(algid) < MLpnl.codings[1]:
	# 						#print(u'to database')
	# 						MLpnl.setMDate.Table = u'MLinfo'
	# 						MLpnl.setMDate.Additem(u' MLPid, MLname, MLcod',[int(algid), algnm, algcd])
	# 						MLpnl.setMDate.Table = u'MLAlgo'
	# 						MLpnl.setMDate.Additem(u' MLcod, MLAsrc',[algcd, ifil])
	# 						wx.MessageBox(_(u'Your source Add to list Successfully.'))
	# 					else:
	# 						wx.MessageBox(_(u'Please attend to coding range!'))
	# 				else:
	# 					wx.MessageBox(_(u'Some fields is empty or wrong ! try again!'))



			#print(MLpnl.getMData.AllML(u' join MLPane on MLinfo.MLPid = MLPane.MLPid join MLAlgo on MLAlgo.MLcod = MLinfo.MLcod'))
			#print(MLpnl.TLC1.GetSelection())
			#tclslct = MLpnl.TLC1.GetSelection()
			#print(MLpnl.TLC1.GetItemText(tclslct,0))
			#print(MLpnl.TLC1.GetItemText(tclslct, 1))
			#print(MLpnl.ChsBok.GetChoiceCtrl())

			#lebls = [u'Par. Pane Name',u'Par. Pane code',u'Par. Pane file']
			#lebls = [u'Algorithm Name',u'Algorithm Code',u'Algorithm file']
			#data = []
			#dlg = wx.Dialog(self.GetFrame(), -1)
			#pnl = MyPanel4(dlg,lebls,data)
			#dlg.SetSize((480,190))
			#dlg.SetLabel(u'Add MLA to List')
			#dlg.ShowModal()
			#dlg.Destroy()

	# def tst(self, event):
	# 	event.Skip()



#In the name og GOD
# ! use/bin/env python
#This file for connect to database interface

'''
   General Purpose Database Systems
    *MySQL
    *Oracle
    *PostgreSQL
    *Microsoft SQL Server
    *Microsoft Access

    for Sqlite        import sqlite3
    for Mysql         import mysql.connector
    for PostgerSQL    import psycopg2
    for Oracle        import cx_Oracle
    for MS SQL Server import pymssql
    for MS Access     import pyodbc

    for MongoDB       import pymongo
'''

def ForSqlitDb(database):
	'''

	:param database:
	:return: Connection
	'''
	import sqlite3
	mydb = sqlite3.connect(database)
	mydb.row_factory = sqlite3.Row
	return mydb

def ForMySqldb(database,user,pswrd,host="localhost"):
	'''

	:param database:
	:param user:
	:param pswrd:
	:param host: localhost
	:return: Connector
	'''
	import mysql.connector

	config = {
		"host": host,
		"port": 3306,
		"database": database,
		"user": user,
		"password": pswrd,
		"charset": "utf8",
		"use_unicode": True,
		"get_warnings": True,
	}

	mydb = mysql.connector.Connect(**config)
	# mydb = mysql.connector.connect(
	# 	host=host,
	# 	user=user,
	# 	password=pswrd,
	# 	database=database
	# )

	return mydb

def ForPostgrSql(database,user,pswrd,host="localhost",port="5432"):
	'''

	:param database:
	:param user:
	:param pswrd:
	:param host: localhost
	:param port: default=5432
	:return: Connection
	'''
	import psycopg2
	#print(database,user,pswrd,host,port)
	mydb = psycopg2.connect(database=database, user=user, password=pswrd, host=host, port=port)

	return  mydb

def ForOraclSqldb(database,user,userpwd,host="localhost",port='1521'):
	'''

	:param database:
	:param user:
	:param userpwd:
	:param host: localhost
	:param port: 1521
	:return: Connection
	'''
	import cx_Oracle
	'''
	# Create a table in Oracle database
	try:
		con = cx_Oracle.connect('tiger/scott@localhost:1521/xe')
		print(con.version)
		:return con
	except cx_Oracle.DatabaseError as e:
		print("There is a problem with Oracle", e)
	# by writing finally if any error occurs
	# then also we can close the all database operation
	finally:
		if con:
			con.close()
    '''

	# Establish the database connection

	#mydb = cx_Oracle.connect(user=user, password=userpwd,dsn=host+'/'+database)
	with cx_Oracle.connect(user=user, password=userpwd,dsn=host+':'+str(port)+'/'+database) as mydb:

		return mydb
	#return mydb
'''


	with cx_Oracle.connect(user=user, password=password,
	                       dsn="dbhost.example.com/orclpdb1",
	                       encoding="UTF-8") as connection:
		cursor = connection.cursor()
		cursor.execute("insert into SomeTable values (:1, :2)",
		               (1, "Some string"))
		connection.commit()
'''

def ForMsSqlOdbc(database,user,pswrd,host='localhost\sqlexpress'):
	import pyodbc
	# Some other example server values are
	# server = 'localhost\sqlexpress' # for a named instance
	# server = 'myserver,port' # to specify an alternate port
	server = host
	database = database
	username = user
	password = pswrd
	cnxn = pyodbc.connect(
		'DRIVER={ODBC Driver 17 for SQL Server};SERVER=' + server + ';DATABASE=' + database + ';UID=' + username + ';PWD=' + password)

	return cnxn

def ForMsSqlSrv(database,user,pswrd,host='localhost\sqlexpress'):
	import pymssql
	mydb = pymssql.connect(server=host, user=user,
	                       password=pswrd, database=database)
	return mydb




def ForMongoDb(database,host="mongodb://localhost:27017/"):
	import pymongo
	myclient = pymongo.MongoClient(host)
	mydb = myclient[database]
	return mydb
	# mycol = mydb["customers"]
	# mydict = {"name": "John", "address": "Highway 37"}
	# x = mycol.insert_one(mydict)
	# mylist = [
	# 	{"name": "Amy", "address": "Apple st 652"},
	# 	{"name": "Hannah", "address": "Mountain 21"},
	# 	{"name": "Michael", "address": "Valley 345"},
	# 	{"name": "Sandy", "address": "Ocean blvd 2"},
	# 	{"name": "Betty", "address": "Green Grass 1"},
	# 	{"name": "Richard", "address": "Sky st 331"},
	# 	{"name": "Susan", "address": "One way 98"},
	# 	{"name": "Vicky", "address": "Yellow Garden 2"},
	# 	{"name": "Ben", "address": "Park Lane 38"},
	# 	{"name": "William", "address": "Central st 954"},
	# 	{"name": "Chuck", "address": "Main Road 989"},
	# 	{"name": "Viola", "address": "Sideway 1633"}
	# ]
	#
	# x = mycol.insert_many(mylist)
	# x = mycol.find_one()
	# myquery = {"address": "Park Lane 38"}
	# mydoc = mycol.find(myquery)
	# mydoc = mycol.find().sort("name")